==> aws-cdk.aws-neptune-alpha-2.2.0a0.tar.gz: package/lib/instance.d.ts <==
import * as cdk from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { IDatabaseCluster } from './cluster';
import { Endpoint } from './endpoint';
import { IParameterGroup } from './parameter-group';
/**
 * (experimental) Possible Instances Types to use in Neptune cluster used for defining {@link DatabaseInstanceProps.instanceType}.
 *
 * @experimental
 */
export declare class InstanceType {
    /**
     * (experimental) db.r6g.large.
     *
     * @experimental
     */
    static readonly R6G_LARGE: InstanceType;
    /**
     * (experimental) db.r6g.xlarge.
     *
     * @experimental
     */
    static readonly R6G_XLARGE: InstanceType;
    /**
     * (experimental) db.r6g.2xlarge.
     *
     * @experimental
     */
    static readonly R6G_2XLARGE: InstanceType;
    /**
     * (experimental) db.r6g.4xlarge.
     *
     * @experimental
     */
    static readonly R6G_4XLARGE: InstanceType;
    /**
     * (experimental) db.r6g.8xlarge.
     *
     * @experimental
     */
    static readonly R6G_8XLARGE: InstanceType;
    /**
     * (experimental) db.r6g.12xlarge.
     *
     * @experimental
     */
    static readonly R6G_12XLARGE: InstanceType;
    /**
     * (experimental) db.r6g.16xlarge.
     *
     * @experimental
     */
    static readonly R6G_16XLARGE: InstanceType;
    /**
     * (experimental) db.t4g.medium.
     *
     * @experimental
     */
    static readonly T4G_MEDIUM: InstanceType;
    /**
     * (experimental) db.r5.large.
     *
     * @experimental
     */
    static readonly R5_LARGE: InstanceType;
    /**
     * (experimental) db.r5.xlarge.
     *
     * @experimental
     */
    static readonly R5_XLARGE: InstanceType;
    /**
     * (experimental) db.r5.2xlarge.
     *
     * @experimental
     */
    static readonly R5_2XLARGE: InstanceType;
    /**
     * (experimental) db.r5.4xlarge.
     *
     * @experimental
     */
    static readonly R5_4XLARGE: InstanceType;
    /**
     * (experimental) db.r5.8xlarge.
     *
     * @experimental
     */
    static readonly R5_8XLARGE: InstanceType;
    /**
     * (experimental) db.r5.12xlarge.
     *
     * @experimental
     */
    static readonly R5_12XLARGE: InstanceType;
    /**
     * (experimental) db.r5.24xlarge.
     *
     * @experimental
     */
    static readonly R5_24XLARGE: InstanceType;
    /**
     * (experimental) db.r4.large.
     *
     * @experimental
     */
    static readonly R4_LARGE: InstanceType;
    /**
     * (experimental) db.r4.xlarge.
     *
     * @experimental
     */
    static readonly R4_XLARGE: InstanceType;
    /**
     * (experimental) db.r4.2xlarge.
     *
     * @experimental
     */
    static readonly R4_2XLARGE: InstanceType;
    /**
     * (experimental) db.r4.4xlarge.
     *
     * @experimental
     */
    static readonly R4_4XLARGE: InstanceType;
    /**
     * (experimental) db.r4.8xlarge.
     *
     * @experimental
     */
    static readonly R4_8XLARGE: InstanceType;
    /**
     * (experimental) db.t3.medium.
     *
     * @experimental
     */
    static readonly T3_MEDIUM: InstanceType;
    /**
     * (experimental) Build an InstanceType from given string or token, such as CfnParameter.
     *
     * @experimental
     */
    static of(instanceType: string): InstanceType;
    /**
     * @internal
     */
    readonly _instanceType: string;
    private constructor();
}
/**
 * (experimental) A database instance.
 *
 * @experimental
 */
export interface IDatabaseInstance extends cdk.IResource {
    /**
     * (experimental) The instance identifier.
     *
     * @experimental
     */
    readonly instanceIdentifier: string;
    /**
     * (experimental) The instance endpoint.
     *
     * @experimental
     */
    readonly instanceEndpoint: Endpoint;
    /**
     * (experimental) The instance endpoint address.
     *
     * @experimental
     * @attribute Endpoint
     */
    readonly dbInstanceEndpointAddress: string;
    /**
     * (experimental) The instance endpoint port.
     *
     * @experimental
     * @attribute Port
     */
    readonly dbInstanceEndpointPort: string;
}
/**
 * (experimental) Properties that describe an existing instance.
 *
 * @experimental
 */
export interface DatabaseInstanceAttributes {
    /**
     * (experimental) The instance identifier.
     *
     * @experimental
     */
    readonly instanceIdentifier: string;
    /**
     * (experimental) The endpoint address.
     *
     * @experimental
     */
    readonly instanceEndpointAddress: string;
    /**
     * (experimental) The database port.
     *
     * @experimental
     */
    readonly port: number;
}
/**
 * (experimental) Construction properties for a DatabaseInstanceNew.
 *
 * @experimental
 */
export interface DatabaseInstanceProps {
    /**
     * (experimental) The Neptune database cluster the instance should launch into.
     *
     * @experimental
     */
    readonly cluster: IDatabaseCluster;
    /**
     * (experimental) What type of instance to start for the replicas.
     *
     * @experimental
     */
    readonly instanceType: InstanceType;
    /**
     * (experimental) The name of the Availability Zone where the DB instance will be located.
     *
     * @default - no preference
     * @experimental
     */
    readonly availabilityZone?: string;
    /**
     * (experimental) A name for the DB instance.
     *
     * If you specify a name, AWS CloudFormation
     * converts it to lowercase.
     *
     * @default - a CloudFormation generated name
     * @experimental
     */
    readonly dbInstanceName?: string;
    /**
     * (experimental) The DB parameter group to associate with the instance.
     *
     * @default no parameter group
     * @experimental
     */
    readonly parameterGroup?: IParameterGroup;
    /**
     * (experimental) The CloudFormation policy to apply when the instance is removed from the stack or replaced during an update.
     *
     * @default RemovalPolicy.Retain
     * @experimental
     */
    readonly removalPolicy?: cdk.RemovalPolicy;
}
/**
 * (experimental) A database instance.
 *
 * @experimental
 * @resource AWS::Neptune::DBInstance
 */
export declare class DatabaseInstance extends cdk.Resource implements IDatabaseInstance {
    /**
     * (experimental) Import an existing database instance.
     *
     * @experimental
     */
    static fromDatabaseInstanceAttributes(scope: Construct, id: string, attrs: DatabaseInstanceAttributes): IDatabaseInstance;
    /**
     * (experimental) The instance's database cluster.
     *
     * @experimental
     */
    readonly cluster: IDatabaseCluster;
    /**
     * (experimental) The instance identifier.
     *
     * @experimental
     * @inheritdoc true
     */
    readonly instanceIdentifier: string;
    /**
     * (experimental) The instance endpoint.
     *
     * @experimental
     * @inheritdoc true
     */
    readonly instanceEndpoint: Endpoint;
    /**
     * (experimental) The instance endpoint address.
     *
     * @experimental
     * @inheritdoc true
     */
    readonly dbInstanceEndpointAddress: string;
    /**
     * (experimental) The instance endpoint port.
     *
     * @experimental
     * @inheritdoc true
     */
    readonly dbInstanceEndpointPort: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: DatabaseInstanceProps);
}

==> aws-cdk.aws-neptune-alpha-2.24.1a0.tar.gz: package/lib/instance.d.ts <==
import * as cdk from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { IDatabaseCluster } from './cluster';
import { Endpoint } from './endpoint';
import { IParameterGroup } from './parameter-group';
/**
 * Possible Instances Types to use in Neptune cluster
 * used for defining {@link DatabaseInstanceProps.instanceType}.
 */
export declare class InstanceType {
    /**
     * db.r6g.large
     */
    static readonly R6G_LARGE: InstanceType;
    /**
     * db.r6g.xlarge
     */
    static readonly R6G_XLARGE: InstanceType;
    /**
     * db.r6g.2xlarge
     */
    static readonly R6G_2XLARGE: InstanceType;
    /**
     * db.r6g.4xlarge
     */
    static readonly R6G_4XLARGE: InstanceType;
    /**
     * db.r6g.8xlarge
     */
    static readonly R6G_8XLARGE: InstanceType;
    /**
    * db.r6g.12xlarge
    */
    static readonly R6G_12XLARGE: InstanceType;
    /**
     * db.r6g.16xlarge
     */
    static readonly R6G_16XLARGE: InstanceType;
    /**
     * db.t4g.medium
     */
    static readonly T4G_MEDIUM: InstanceType;
    /**
     * db.r5.large
     */
    static readonly R5_LARGE: InstanceType;
    /**
     * db.r5.xlarge
     */
    static readonly R5_XLARGE: InstanceType;
    /**
     * db.r5.2xlarge
     */
    static readonly R5_2XLARGE: InstanceType;
    /**
     * db.r5.4xlarge
     */
    static readonly R5_4XLARGE: InstanceType;
    /**
     * db.r5.8xlarge
     */
    static readonly R5_8XLARGE: InstanceType;
    /**
     * db.r5.12xlarge
     */
    static readonly R5_12XLARGE: InstanceType;
    /**
     * db.r5.24xlarge
     */
    static readonly R5_24XLARGE: InstanceType;
    /**
     * db.r4.large
     */
    static readonly R4_LARGE: InstanceType;
    /**
     * db.r4.xlarge
     */
    static readonly R4_XLARGE: InstanceType;
    /**
     * db.r4.2xlarge
     */
    static readonly R4_2XLARGE: InstanceType;
    /**
     * db.r4.4xlarge
     */
    static readonly R4_4XLARGE: InstanceType;
    /**
     * db.r4.8xlarge
     */
    static readonly R4_8XLARGE: InstanceType;
    /**
     * db.t3.medium
     */
    static readonly T3_MEDIUM: InstanceType;
    /**
     * Build an InstanceType from given string or token, such as CfnParameter.
     */
    static of(instanceType: string): InstanceType;
    /**
     * @internal
     */
    readonly _instanceType: string;
    private constructor();
}
/**
 * A database instance
 */
export interface IDatabaseInstance extends cdk.IResource {
    /**
     * The instance identifier.
     */
    readonly instanceIdentifier: string;
    /**
     * The instance endpoint.
     */
    readonly instanceEndpoint: Endpoint;
    /**
     * The instance endpoint address.
     *
     * @attribute Endpoint
     */
    readonly dbInstanceEndpointAddress: string;
    /**
     * The instance endpoint port.
     *
     * @attribute Port
     */
    readonly dbInstanceEndpointPort: string;
}
/**
 * Properties that describe an existing instance
 */
export interface DatabaseInstanceAttributes {
    /**
     * The instance identifier.
     */
    readonly instanceIdentifier: string;
    /**
     * The endpoint address.
     */
    readonly instanceEndpointAddress: string;
    /**
     * The database port.
     */
    readonly port: number;
}
/**
 * Construction properties for a DatabaseInstanceNew
 */
export interface DatabaseInstanceProps {
    /**
     * The Neptune database cluster the instance should launch into.
     */
    readonly cluster: IDatabaseCluster;
    /**
     * What type of instance to start for the replicas
     */
    readonly instanceType: InstanceType;
    /**
     * The name of the Availability Zone where the DB instance will be located.
     *
     * @default - no preference
     */
    readonly availabilityZone?: string;
    /**
     * A name for the DB instance. If you specify a name, AWS CloudFormation
     * converts it to lowercase.
     *
     * @default - a CloudFormation generated name
     */
    readonly dbInstanceName?: string;
    /**
     * The DB parameter group to associate with the instance.
     *
     * @default no parameter group
     */
    readonly parameterGroup?: IParameterGroup;
    /**
     * The CloudFormation policy to apply when the instance is removed from the
     * stack or replaced during an update.
     *
     * @default RemovalPolicy.Retain
     */
    readonly removalPolicy?: cdk.RemovalPolicy;
}
/**
 * A database instance
 *
 * @resource AWS::Neptune::DBInstance
 */
export declare class DatabaseInstance extends cdk.Resource implements IDatabaseInstance {
    /**
     * Import an existing database instance.
     */
    static fromDatabaseInstanceAttributes(scope: Construct, id: string, attrs: DatabaseInstanceAttributes): IDatabaseInstance;
    /**
     * The instance's database cluster
     */
    readonly cluster: IDatabaseCluster;
    /**
     * @inheritdoc
     */
    readonly instanceIdentifier: string;
    /**
     * @inheritdoc
     */
    readonly instanceEndpoint: Endpoint;
    /**
     * @inheritdoc
     */
    readonly dbInstanceEndpointAddress: string;
    /**
     * @inheritdoc
     */
    readonly dbInstanceEndpointPort: string;
    constructor(scope: Construct, id: string, props: DatabaseInstanceProps);
}
